@@ -1,20 +1,22 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for forecast service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.forecast import ForecastServiceClient
-
-    session = boto3.Session()
+    from mypy_boto3_forecast import ForecastServiceClient
 
     client: ForecastServiceClient = boto3.client("forecast")
-    session_client: ForecastServiceClient = session.client("forecast")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_forecast.paginator import (
     ListDatasetGroupsPaginator,
     ListDatasetImportJobsPaginator,
@@ -75,14 +77,14 @@ class Exceptions:
 
 class ForecastServiceClient:
     """
-    [ForecastService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client)
+    [ForecastService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.can_paginate)
         """
 
     def create_dataset(
@@ -103,7 +105,7 @@ class ForecastServiceClient:
         EncryptionConfig: "EncryptionConfigTypeDef" = None,
     ) -> CreateDatasetResponseTypeDef:
         """
-        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_dataset)
+        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.create_dataset)
         """
 
     def create_dataset_group(
@@ -121,7 +123,7 @@ class ForecastServiceClient:
         DatasetArns: List[str] = None,
     ) -> CreateDatasetGroupResponseTypeDef:
         """
-        [Client.create_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
+        [Client.create_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
         """
 
     def create_dataset_import_job(
@@ -132,21 +134,21 @@ class ForecastServiceClient:
         TimestampFormat: str = None,
     ) -> CreateDatasetImportJobResponseTypeDef:
         """
-        [Client.create_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
+        [Client.create_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
         """
 
     def create_forecast(
         self, ForecastName: str, PredictorArn: str, ForecastTypes: List[str] = None
     ) -> CreateForecastResponseTypeDef:
         """
-        [Client.create_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_forecast)
+        [Client.create_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.create_forecast)
         """
 
     def create_forecast_export_job(
         self, ForecastExportJobName: str, ForecastArn: str, Destination: "DataDestinationTypeDef"
     ) -> CreateForecastExportJobResponseTypeDef:
         """
-        [Client.create_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
+        [Client.create_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
         """
 
     def create_predictor(
@@ -164,71 +166,71 @@ class ForecastServiceClient:
         EncryptionConfig: "EncryptionConfigTypeDef" = None,
     ) -> CreatePredictorResponseTypeDef:
         """
-        [Client.create_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_predictor)
+        [Client.create_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.create_predictor)
         """
 
     def delete_dataset(self, DatasetArn: str) -> None:
         """
-        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.delete_dataset)
+        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.delete_dataset)
         """
 
     def delete_dataset_group(self, DatasetGroupArn: str) -> None:
         """
-        [Client.delete_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
+        [Client.delete_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
         """
 
     def delete_dataset_import_job(self, DatasetImportJobArn: str) -> None:
         """
-        [Client.delete_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
+        [Client.delete_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
         """
 
     def delete_forecast(self, ForecastArn: str) -> None:
         """
-        [Client.delete_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.delete_forecast)
+        [Client.delete_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.delete_forecast)
         """
 
     def delete_forecast_export_job(self, ForecastExportJobArn: str) -> None:
         """
-        [Client.delete_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
+        [Client.delete_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
         """
 
     def delete_predictor(self, PredictorArn: str) -> None:
         """
-        [Client.delete_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.delete_predictor)
+        [Client.delete_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.delete_predictor)
         """
 
     def describe_dataset(self, DatasetArn: str) -> DescribeDatasetResponseTypeDef:
         """
-        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.describe_dataset)
+        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.describe_dataset)
         """
 
     def describe_dataset_group(self, DatasetGroupArn: str) -> DescribeDatasetGroupResponseTypeDef:
         """
-        [Client.describe_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
+        [Client.describe_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
         """
 
     def describe_dataset_import_job(
         self, DatasetImportJobArn: str
     ) -> DescribeDatasetImportJobResponseTypeDef:
         """
-        [Client.describe_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
+        [Client.describe_dataset_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
         """
 
     def describe_forecast(self, ForecastArn: str) -> DescribeForecastResponseTypeDef:
         """
-        [Client.describe_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.describe_forecast)
+        [Client.describe_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.describe_forecast)
         """
 
     def describe_forecast_export_job(
         self, ForecastExportJobArn: str
     ) -> DescribeForecastExportJobResponseTypeDef:
         """
-        [Client.describe_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
+        [Client.describe_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
         """
 
     def describe_predictor(self, PredictorArn: str) -> DescribePredictorResponseTypeDef:
         """
-        [Client.describe_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.describe_predictor)
+        [Client.describe_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.describe_predictor)
         """
 
     def generate_presigned_url(
@@ -239,59 +241,59 @@ class ForecastServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
         """
 
     def get_accuracy_metrics(self, PredictorArn: str) -> GetAccuracyMetricsResponseTypeDef:
         """
-        [Client.get_accuracy_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
+        [Client.get_accuracy_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
         """
 
     def list_dataset_groups(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListDatasetGroupsResponseTypeDef:
         """
-        [Client.list_dataset_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
+        [Client.list_dataset_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
         """
 
     def list_dataset_import_jobs(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListDatasetImportJobsResponseTypeDef:
         """
-        [Client.list_dataset_import_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
+        [Client.list_dataset_import_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
         """
 
     def list_datasets(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListDatasetsResponseTypeDef:
         """
-        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.list_datasets)
+        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.list_datasets)
         """
 
     def list_forecast_export_jobs(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListForecastExportJobsResponseTypeDef:
         """
-        [Client.list_forecast_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
+        [Client.list_forecast_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
         """
 
     def list_forecasts(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListForecastsResponseTypeDef:
         """
-        [Client.list_forecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.list_forecasts)
+        [Client.list_forecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.list_forecasts)
         """
 
     def list_predictors(
         self, NextToken: str = None, MaxResults: int = None, Filters: List[FilterTypeDef] = None
     ) -> ListPredictorsResponseTypeDef:
         """
-        [Client.list_predictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.list_predictors)
+        [Client.list_predictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.list_predictors)
         """
 
     def update_dataset_group(self, DatasetGroupArn: str, DatasetArns: List[str]) -> Dict[str, Any]:
         """
-        [Client.update_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
+        [Client.update_dataset_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
         """
 
     @overload
@@ -299,7 +301,7 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_dataset_groups"]
     ) -> ListDatasetGroupsPaginator:
         """
-        [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+        [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
         """
 
     @overload
@@ -307,13 +309,13 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_dataset_import_jobs"]
     ) -> ListDatasetImportJobsPaginator:
         """
-        [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+        [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
         """
 
     @overload
@@ -321,17 +323,20 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_forecast_export_jobs"]
     ) -> ListForecastExportJobsPaginator:
         """
-        [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+        [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_forecasts"]) -> ListForecastsPaginator:
         """
-        [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+        [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_predictors"]) -> ListPredictorsPaginator:
         """
-        [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+        [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
