@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for forecast service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.forecast import (
+
+    from mypy_boto3_forecast import ForecastServiceClient
+    from mypy_boto3_forecast.paginator import (
         ListDatasetGroupsPaginator,
         ListDatasetImportJobsPaginator,
         ListDatasetsPaginator,
@@ -21,10 +25,12 @@ Usage::
     list_forecast_export_jobs_paginator: ListForecastExportJobsPaginator = client.get_paginator("list_forecast_export_jobs")
     list_forecasts_paginator: ListForecastsPaginator = client.get_paginator("list_forecasts")
     list_predictors_paginator: ListPredictorsPaginator = client.get_paginator("list_predictors")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_forecast.type_defs import (
     FilterTypeDef,
     ListDatasetGroupsResponseTypeDef,
@@ -36,7 +42,6 @@ from mypy_boto3_forecast.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListDatasetGroupsPaginator",
     "ListDatasetImportJobsPaginator",
@@ -49,77 +54,77 @@ __all__ = (
 
 class ListDatasetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+    [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDatasetGroupsResponseTypeDef]:
         """
-        [ListDatasetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups.paginate)
+        [ListDatasetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups.paginate)
         """
 
 
 class ListDatasetImportJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+    [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDatasetImportJobsResponseTypeDef]:
         """
-        [ListDatasetImportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs.paginate)
+        [ListDatasetImportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs.paginate)
         """
 
 
 class ListDatasetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDatasetsResponseTypeDef]:
         """
-        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListDatasets.paginate)
+        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListDatasets.paginate)
         """
 
 
 class ListForecastExportJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+    [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListForecastExportJobsResponseTypeDef]:
         """
-        [ListForecastExportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs.paginate)
+        [ListForecastExportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs.paginate)
         """
 
 
 class ListForecastsPaginator(Boto3Paginator):
     """
-    [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+    [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListForecastsResponseTypeDef]:
         """
-        [ListForecasts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListForecasts.paginate)
+        [ListForecasts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListForecasts.paginate)
         """
 
 
 class ListPredictorsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+    [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPredictorsResponseTypeDef]:
         """
-        [ListPredictors.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Paginator.ListPredictors.paginate)
+        [ListPredictors.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/forecast.html#ForecastService.Paginator.ListPredictors.paginate)
         """
